function [NAtype, NAlat, NAlon, NAalt,  NAfreq, NArange, NAid] = Get_NavAid_Data(NavAidSet)
%% -----------------------------------------------------------------------------------------------------------
% Version:      20/09/2015    
% (c):          Vicente Calabuig Simón
%               vicasim@etsid.upv.es
%
% 1.- Utilidad:
%
%       Desglosa los datos referentes a un conjunto de radioayudas en distintos arrays.      
%
% 2.- Parámetros de entrada:
% 
%       NavAidSet : Conjunto de radioayudas de interés en formato:  '12  39.48395000 -000.47030600    203 11010  18       0.200 IVC  LEVC 30  DME-ILS'
%                                                                   '3  39.48564700 -000.48304400    200 11610 130   -2.0 VLC  VALENCIA VOR-DME'
%                                                                   '12  39.48570300 -000.48305600    200 11610 130    0.0 VLC  VALENCIA VOR-DME'
%                                                                   '12  39.49402778 -000.49677778    256 11150  25       0.000 VLN  LEVC 12  DME-ILS'
%                                                                   .
%                                                                   .
%                                                                   .
% 3.- Parámetros de salida:
%
%       NAtype:      Array con el tipo de radioayuda (3: VOR,   12 : DME,   13: DME)
%       NAlat:       Array con las latitudes de las radioayudas ordenadas.  (º)
%       NAlon:       Array con las longitudes de las radioayudas ordenadas. (º)
%       NAalt:       Array con las altitudes de las radioayudas ordenadas.  (ft)
%       NAfreq:      Array con las frequencias de sintonización de las radioayudas ordenadas. (MHZ x 100)
%       NArange:     Array con las distancias máximas de funcionamiento de las radioayudas.   (NM)
%                                    
%
% 4.- Ejemplo de uso:
%
%   [Database] = Reading_Database('earth_nav.dat', 1, 26590)
%   [NAtype, NAlat, NAlon, NAalt,  NAfreq, NArange] = Get_NavAid_Data(Database);
%% -----------------------------------------------------------------------------------------------------------------------------------
format long;

% Asignaciones iniciales:
NAtype = [];      NAlat = [];     NAlon = [];     NAalt = [];     NAfreq = [];    NArange = [];     NAid ={};
[filas, X] = size(NavAidSet);
for i = 1 : filas
    S          = NavAidSet{i};
    
    type       = S( 1  : 2  );      NAtype (i) = str2num(type);   
    
    lat        = S( 3  : 15 );      NAlat  (i) = str2num(lat);
   
    lon        = S( 16 : 29 );      NAlon  (i) = str2num(lon); 
      
    alt        = S( 30 : 36 );      NAalt  (i) = str2num(alt);
    
    freq       = S( 37 : 42 );      NAfreq (i) = str2num(freq);
    
    range      = S( 43 : 46 );      NArange(i) = str2num(range);  
    
    id         = S( 58 : end );     id= id(~isspace(id));        NAid {i} = id;
   
    
end
% Preferimos los arrays en columna:
NAtype = NAtype';   NAlat = NAlat';     NAlon = NAlon';     NAalt = NAalt';    

NAfreq = NAfreq';   NArange = NArange';     NAid = NAid'; 





 